@@ -731,7 +731,7 @@ void Identity::setPgpAutoEncrypt(bool autoEncrypt)
     setProperty(QLatin1String(s_pgpautoencrypt), autoEncrypt);
 }
 
-bool KIdentityManagementCore::Identity::autocryptEnabled() const
+bool Identity::autocryptEnabled() const
 {
     const auto var = property(QLatin1String(s_autocryptEnabled));
     if (var.isNull()) {
@@ -746,7 +746,7 @@ void Identity::setAutocryptEnabled(const bool on)
     setProperty(QLatin1String(s_autocryptEnabled), on);
 }
 
-bool KIdentityManagementCore::Identity::autocryptPrefer() const
+bool Identity::autocryptPrefer() const
 {
     const auto var = property(QLatin1String(s_autocryptPrefer));
     if (var.isNull()) {
@@ -761,7 +761,7 @@ void Identity::setAutocryptPrefer(const bool on)
     setProperty(QLatin1String(s_autocryptPrefer), on);
 }
 
-bool KIdentityManagementCore::Identity::encryptionOverride() const
+bool Identity::encryptionOverride() const
 {
     const auto var = property(QLatin1String(s_encryptionOverride));
     if (var.isNull()) {
@@ -776,7 +776,7 @@ void Identity::setEncryptionOverride(const bool on)
     setProperty(QLatin1String(s_encryptionOverride), on);
 }
 
-bool KIdentityManagementCore::Identity::warnNotEncrypt() const
+bool Identity::warnNotEncrypt() const
 {
     const auto var = property(QLatin1String(s_warnnotencrypt));
     if (var.isNull()) {
@@ -791,7 +791,7 @@ void Identity::setWarnNotEncrypt(const bool on)
     setProperty(QLatin1String(s_warnnotencrypt), on);
 }
 
-bool KIdentityManagementCore::Identity::warnNotSign() const
+bool Identity::warnNotSign() const
 {
     const auto var = property(QLatin1String(s_warnnotsign));
     if (var.isNull()) {
